@@ -75,7 +75,7 @@ def cli(*args, write_file="-", human=False, version=False, command=None, **kwds)
     motion = quakeio.read(**kwds)
     if human:
         motion = quakeio.core.write_pretty(motion)
-    if "angle" in kwds:
+    if "angle" in kwds and kwds["angle"]:
         quakeio.core.rotate(motion, float(kwds["angle"]))
     quakeio.write(write_file, motion, **kwds)
     print("\n")
