@@ -16,12 +16,9 @@ class GroundMotionEvent(dict):
         dict.__init__(self, **records)
         self.event_date = event_date
 
-    def serialize(self, serialize_data=True) -> dict:
-        return {k: v.serialize() for k, v in self.items()}
+    def serialize(self, serialize_data=True, **kwds) -> dict:
+        return {k: v.serialize(**kwds) for k, v in self.items()}
 
-# def rotate_horizontal(angle,x,y,overwrite=True):
-#     vect = np.asarray([x,y])
-#     np.matmul(rotation, vect, out = vect)
 
 class GroundMotionRecord(dict):
     """
@@ -30,8 +27,8 @@ class GroundMotionRecord(dict):
     def __init__(self, records: dict = {}, **kwds):
         dict.__init__(self, **records)
 
-    def serialize(self, serialize_data=True) -> dict:
-        return {k: v.serialize() for k, v in self.items()}
+    def serialize(self, serialize_data=True, **kwds) -> dict:
+        return {k: v.serialize(**kwds) for k, v in self.items()}
 
     def rotate(self, angle=None, rotation=None):
         rx, ry = np.array([
@@ -54,21 +51,35 @@ class GroundMotionRecord(dict):
 
 
 class GroundMotionComponent(dict):
+    schema_dir = Path(__file__).parents[2] / "etc/schemas"
+    schema_file = schema_dir / "component.schema.json"
+
     def __init__(self, accel, veloc, displ, meta={}):
         self.accel = accel
         self.displ = displ
         self.veloc = veloc
         dict.__init__(self, **meta)
 
-    def serialize(self, serialize_data=True) -> dict:
-        ret = dict(self)
-        ret.update(
-            {
-                **self.accel.serialize("accel", serialize_data=serialize_data),
-                **self.veloc.serialize("veloc", serialize_data=serialize_data),
-                **self.displ.serialize("displ", serialize_data=serialize_data),
-            }
-        )
+    def serialize(self, 
+            ljust=0, 
+            serialize_data  = True, 
+            serialize_series= True, 
+            humanize_keys   = False, 
+            **kwds
+    ) -> dict:
+        if humanize_keys:
+            key_name = get_schema_key_map(self.schema_file)
+            ret = {key_name(k).ljust(ljust,"."): val for k,val in self.items()}
+        else:
+            ret = dict(self)
+        if serialize_series:
+            ret.update(
+                {
+                    **self.accel.serialize("accel", serialize_data=serialize_data, **kwds),
+                    **self.veloc.serialize("veloc", serialize_data=serialize_data, **kwds),
+                    **self.displ.serialize("displ", serialize_data=serialize_data, **kwds),
+                }
+            )
         return ret
 
 
@@ -81,13 +92,14 @@ class GroundMotionSeries(np.ndarray):
                 setattr(obj, k, v)
         return obj
 
-    def serialize(self, key=None, serialize_data=True):
+    def serialize(self, key=None, summarize=False, serialize_data=True, humanize_keys=False):
         if key is None:
             key = self.series_type
+
         attributes = {
             ".".join((key, k)): v for k, v in self.__dict__.items() if k[0] != "_"
         }
-        if serialize_data:
+        if serialize_data and not summarize:
             attributes.update({key: list(self)})
         return attributes
 
@@ -114,11 +126,18 @@ def rotate(data, angle):
             except KeyError:
                 warnings.warn(f"Not rotating record {name}")
 
+def get_schema_key_map(schema_file):
+    with open(schema_file, "r") as f:
+        schema = json.load(f)["properties"]
+    def get_name(key):
+        return schema[key]["title"] if key in schema else key
+    return get_name
+    
 
 def write_pretty(data):
     output = copy(data)
     schema_dir = Path(__file__).parents[2] / "etc/schemas"
-    schema_file = schema_dir / "record.schema.json"
+    schema_file = schema_dir / "component.schema.json"
     with open(schema_file, "r") as f:
         schema = json.load(f)["properties"]
     if isinstance(data, GroundMotionComponent):
@@ -127,7 +146,6 @@ def write_pretty(data):
                 output[schema[k]["title"]] = output.pop(k)
             else:
                 pass
-                #del output[k]
 
     elif isinstance(data, GroundMotionEvent):
         for name, record in data.items():
@@ -139,6 +157,6 @@ def write_pretty(data):
                         output[name][dirn][schema[k]["title"]] = output[name][dirn].pop(k)
                     else:
                         pass
-                        #del output[name][dirn][k]
 
     return output
+
